@@ -55,7 +55,7 @@ import com.openexchange.config.lean.Property;
  * Contains all properties of the OpenID feature.
  *
  * @author <a href="mailto:vitali.sjablow@open-xchange.com">Vitali Sjablow</a>
- * @since v7.8.4
+ * @since v7.10.0
  */
 public enum OIDCProperty implements Property {
     /**
@@ -92,4 +92,10 @@ public enum OIDCProperty implements Property {
         throw new IllegalArgumentException("The object cannot be converted to the specified type '" + clazz.getCanonicalName() + "'");
 
     }
+
+    @Override
+    public Object getDefaultValue() {
+        return defaultValue;
+    }
+
 }
